<template>
  <LoadingLayout :loading="state.loading">
    <AppContainer>
      <ProTableV2
        v-bind="proTableProps"
        :columns="column"
        :operationBtns="operationBtns"
        :autoHeight="false"
        :tableProps="{
          maxHeight: '400px',
        }"
      >
      </ProTableV2>
      <BatchChangeRecordDetailDialog v-bind="dialogProps"></BatchChangeRecordDetailDialog>
    </AppContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import {
  AppContainer,
  useTable,
  ProTableV2,
  defineOperationBtns,
  useFormDialog,
} from '@bole-core/components';
import * as insureBatchBillServices from '@/services/api/InsureBatchBill';
import { OrderInputType } from '@bole-core/core';
import BatchChangeRecordDetailDialog from './BatchChangeRecordDetailDialog.vue';

defineOptions({
  name: 'BatchChangeRecordView',
});

const column: API.CustomModuleColumnDto[] = [
  {
    id: '1',
    enCode: 'name',
    name: '批单号',
  },
  {
    id: '2',
    enCode: 'name',
    name: '批改类型',
  },
  {
    id: '3',
    enCode: 'name',
    name: '申请日期',
  },
  {
    id: '4',
    enCode: 'idNumber',
    name: '批改生效日期',
  },
  {
    id: '5',
    enCode: 'idNumber',
    name: '在保人数',
  },
  {
    id: '6',
    enCode: 'idNumber',
    name: '原在保人数',
  },
  {
    id: '7',
    enCode: 'idNumber',
    name: '新增',
  },
  {
    id: '8',
    enCode: 'idNumber',
    name: '减少',
  },
  {
    id: '9',
    enCode: 'idNumber',
    name: '批单状态',
  },
];

const operationBtns = defineOperationBtns([
  {
    data: {
      enCode: 'detailBtn',
      name: '详情',
    },
    emits: {
      onClick: (role) => handleDetail(role),
    },
    // extraProps: {
    //   hide: (row: API.InsureBatchBillDto) => !row.orderBillFile,
    // },
  },
  {
    data: {
      enCode: 'downloadBtn',
      name: '下载批单',
    },
    emits: {
      onClick: (role) => handleDownload(role),
    },
    // extraProps: {
    //   hide: (row: API.InsureBatchBillDto) => !row.orderBillFile,
    // },
  },
]);

const route = useRoute();
const id = route.params.id as string;
const BaseState = {
  loading: true,
};

const state = reactive({ ...BaseState });

const {
  getDataSource: getBatchRefundInfoDetail,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.GetInsuranceBatchBillInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
        insurancePolicyId: id,
      };
      let res = await insureBatchBillServices.getInsureBatchBillList(params, {
        showLoading: !state.loading,
      });
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      keyWord: '',
      orderInput: [{ property: 'id', order: OrderInputType.Asc }],
    },
    columnsRenderProps: {},
  }
);

const { dialogProps, handleEdit } = useFormDialog({
  defaultFormParams: {
    id: '',
  },
});

function handleDetail(row: API.InsureBatchBillDto) {
  handleEdit({
    id: row.insureBatchBillId,
  });
}

function handleDownload(row: API.InsureBatchBillDto) {}

onMounted(async () => {
  await getBatchRefundInfoDetail();
  state.loading = false;
});
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
